@@ -28,8 +28,6 @@ import java.lang.reflect.Proxy;
 import java.lang.reflect.UndeclaredThrowableException;
 import java.net.HttpURLConnection;
 import java.net.URL;
-import java.net.http.HttpConnectTimeoutException;
-import java.net.http.HttpTimeoutException;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
@@ -44,20 +42,20 @@ import java.util.zip.GZIPInputStream;
 
 import javax.xml.namespace.QName;
 import javax.xml.transform.stream.StreamSource;
-import javax.xml.ws.AsyncHandler;
-import javax.xml.ws.BindingProvider;
-import javax.xml.ws.Dispatch;
-import javax.xml.ws.Endpoint;
-import javax.xml.ws.Response;
-import javax.xml.ws.Service;
-import javax.xml.ws.WebServiceException;
-import javax.xml.ws.handler.MessageContext;
-import javax.xml.ws.soap.SOAPFaultException;
 
 import org.w3c.dom.Document;
 
 import com.google.common.io.Files;
 
+import jakarta.xml.ws.AsyncHandler;
+import jakarta.xml.ws.BindingProvider;
+import jakarta.xml.ws.Dispatch;
+import jakarta.xml.ws.Endpoint;
+import jakarta.xml.ws.Response;
+import jakarta.xml.ws.Service;
+import jakarta.xml.ws.WebServiceException;
+import jakarta.xml.ws.handler.MessageContext;
+import jakarta.xml.ws.soap.SOAPFaultException;
 import org.apache.cxf.Bus;
 import org.apache.cxf.bus.CXFBusFactory;
 import org.apache.cxf.common.logging.LogUtils;
@@ -191,14 +189,14 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
     }
 
     @Test
-    public void testTimeoutConfiguration() throws Exception {
+    public void testTimeoutConfigutation() throws Exception {
 
         SOAPService service = new SOAPService();
         assertNotNull(service);
 
         Greeter greeter = service.getPort(portName, Greeter.class);
         updateAddressPort(greeter, PORT);
-        ((javax.xml.ws.BindingProvider)greeter).getRequestContext().put("javax.xml.ws.client.receiveTimeout",
+        ((jakarta.xml.ws.BindingProvider)greeter).getRequestContext().put("jakarta.xml.ws.client.receiveTimeout",
                                                                         "1");
         try {
             greeter.greetMe("test");
@@ -208,10 +206,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
             if (ex.getCause() != null) {
                 cause = ex.getCause();
             }
-            assertTrue("Timeout cause is expected: " + cause.getClass().getName(), 
-                       cause instanceof java.net.SocketTimeoutException
-                       || cause instanceof HttpConnectTimeoutException
-                       || cause instanceof HttpTimeoutException);
+            assertTrue("Timeout cause is expected", cause instanceof java.net.SocketTimeoutException);
         }
     }
 
@@ -237,7 +232,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
     @Test
     public void testAddPortWithSpecifiedSoap12Binding() throws Exception {
         Service service = Service.create(serviceName);
-        service.addPort(fakePortName, javax.xml.ws.soap.SOAPBinding.SOAP12HTTP_BINDING,
+        service.addPort(fakePortName, jakarta.xml.ws.soap.SOAPBinding.SOAP12HTTP_BINDING,
                         "http://localhost:" + PORT + "/SoapContext/SoapPort");
         Greeter greeter = service.getPort(fakePortName, Greeter.class);
 
@@ -257,7 +252,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
     @Test
     public void testAddPortWithSpecifiedSoap11Binding() throws Exception {
         Service service = Service.create(serviceName);
-        service.addPort(fakePortName, javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
+        service.addPort(fakePortName, jakarta.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
             "http://localhost:" + PORT + "/SoapContext/SoapPort");
         Greeter greeter = service.getPort(fakePortName, Greeter.class);
 
@@ -989,7 +984,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
     @Test
     public void testServerAsync() throws Exception {
         Service service = Service.create(serviceName);
-        service.addPort(fakePortName, javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
+        service.addPort(fakePortName, jakarta.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
             "http://localhost:" + PORT + "/SoapContext/AsyncSoapPort");
         Greeter greeter = service.getPort(fakePortName, Greeter.class);
         String resp = greeter.greetMe("World");
@@ -1000,7 +995,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
     public void testEchoProviderAsync() throws Exception {
         String requestString = "<echo/>";
         Service service = Service.create(serviceName);
-        service.addPort(fakePortName, javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
+        service.addPort(fakePortName, jakarta.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
                         "http://localhost:" + PORT + "/SoapContext/AsyncEchoProvider");
         Dispatch<StreamSource> dispatcher = service.createDispatch(fakePortName,
                                                                    StreamSource.class,
@@ -1022,12 +1017,12 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
         
         String requestString = "<echo/>";
         Service service = Service.create(serviceName);
-        service.addPort(fakePortName, javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
+        service.addPort(fakePortName, jakarta.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
                         "http://localhost:" + PORT + "/SoapContext/AsyncEchoProvider");
         Dispatch<StreamSource> dispatcher = service.createDispatch(fakePortName,
                                                                    StreamSource.class,
                                                                    Service.Mode.PAYLOAD);
-        dispatcher.getRequestContext().put("javax.xml.ws.client.receiveTimeout", "5000");
+        dispatcher.getRequestContext().put("jakarta.xml.ws.client.receiveTimeout", "5000");
         
         StreamSource request = new StreamSource(new ByteArrayInputStream(requestString.getBytes()));
         StreamSource response = dispatcher.invoke(request);
@@ -1053,12 +1048,12 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
         
         String requestString = "<echo/>";
         Service service = Service.create(serviceName);
-        service.addPort(fakePortName, javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
+        service.addPort(fakePortName, jakarta.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
                         "http://localhost:" + PORT + "/SoapContext/AsyncEchoProvider");
         Dispatch<StreamSource> dispatcher = service.createDispatch(fakePortName,
                                                                    StreamSource.class,
                                                                    Service.Mode.PAYLOAD);
-        dispatcher.getRequestContext().put("javax.xml.ws.client.receiveTimeout", "500");
+        dispatcher.getRequestContext().put("jakarta.xml.ws.client.receiveTimeout", "500");
         
         try {
             StreamSource request = new StreamSource(new ByteArrayInputStream(requestString.getBytes()));
@@ -1080,7 +1075,7 @@ public class ClientServerTest extends AbstractBusClientServerTestBase {
     public void testEchoProviderAsyncDecoupledEndpoints() throws Exception {
         String requestString = "<echo/>";
         Service service = Service.create(serviceName);
-        service.addPort(fakePortName, javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
+        service.addPort(fakePortName, jakarta.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING,
                         "http://localhost:" + PORT + "/SoapContext/AsyncEchoProvider");
         Dispatch<StreamSource> dispatcher = service.createDispatch(fakePortName,
                                                                    StreamSource.class,
